==> mono_1.1.8.3.orig.tar.gz: mono-1.1.8.3/mcs/class/corlib/System.Reflection.Emit/Label.cs <==
//
// System.Reflection.Emit/Label.cs
//
// Author:
//   Paolo Molaro (lupus@ximian.com)
//
// (C) 2001 Ximian, Inc.  http://www.ximian.com
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.Runtime.InteropServices;

namespace System.Reflection.Emit {

#if NET_2_0
	[ComVisible (true)]
#endif
	[Serializable]
	public struct Label {
		internal int label;

		internal Label (int val) {
			label = val;
		}

		public override bool Equals (object obj) {
			bool res = obj is Label;

			if (res) {
				Label l = (Label)obj;
				res = (label == l.label);
			}

			return res;
		}

#if NET_2_0
		public bool Equals (Label obj)
		{
			return (label == obj.label);
		}
#endif

		public override int GetHashCode () {
			return label.GetHashCode ();
		}
	}
}

==> mono_4.2.1.102+dfsg2.orig.tar.gz: mono-4.2.1+dfsg2/mcs/class/corlib/System.Reflection.Emit/Label.cs <==
//
// System.Reflection.Emit/Label.cs
//
// Author:
//   Paolo Molaro (lupus@ximian.com)
//
// (C) 2001 Ximian, Inc.  http://www.ximian.com
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if !FULL_AOT_RUNTIME || IOS_REFLECTION
using System.Runtime.InteropServices;

namespace System.Reflection.Emit {

	[ComVisible (true)]
	[Serializable]
	public struct Label {
		internal int label;

		internal Label (int val) {
			label = val;
		}

		public override bool Equals (object obj) {
			bool res = obj is Label;

			if (res) {
				Label l = (Label)obj;
				res = (label == l.label);
			}

			return res;
		}

		public bool Equals (Label obj)
		{
			return (label == obj.label);
		}

		public static bool operator == (Label a, Label b) {
			return a.Equals (b);
		}

		public static bool operator != (Label a, Label b) {
			return !(a == b);
		}

		public override int GetHashCode () {
			return label.GetHashCode ();
		}
	}
}
#endif
